<?php

/*
 * Smarty plugin
 * ------------------------------------------------------------
 * Type:       modifier
 * Name:       bbcode2html
 * Purpose:    Converts BBCode style tags to HTML
 * Author:     Andr Rabold
 * Version:    1.3c
 * Remarks:    Notice that this function does not check for
 *             correct syntax. Try not to use it with invalid
 *             BBCode because this could lead to unexpected
 *             results ;-)
 * What's new: - Fixed a bug with <li>...</li> tags (thanks
 *               to Rob Schultz for pointing this out)
 *
 *             Version 1.3b
 *             - Added more support for phpBB2:
 *               [list]...[/list:u] unordered lists
 *               [list]...[/list:o] ordered lists
 *
 *             Version 1.3
 *             - added support for phpBB2 like tag identifier
 *               like [b:b6a0cef7ea]This is bold[/b:b6a0cef7ea]
 *               (thanks to Rob Schultz)
 *             - added support for quotes within the quote tag
 *               so [quote="foo"]bar[/quote] does work now
 *               correctly
 *             - removed str_replace functions
 *
 *             Version 1.2
 *             - now supports CSS classes:
 *                  ng_email      (mailto links)
 *                  ng_url        (www links)
 *                  ng_quote      (quotes)
 *                  ng_quote_body (quotes)
 *                  ng_code       (source code)
 *                  ng_list       (html lists)
 *                  ng_list_item  (list items)
 *             - replaced slow ereg_replace() functions
 *             - Alterned [quote] and [code] to use CSS classes
 *               instead of HTML <blockquote />, <hr />, ... tags.
 *             - Additional BBCode tags [list] and [*] to display
 *               nice HTML lists. Example:
 *                 [list]
 *                   [*]first item
 *                   [*]second item
 *                   [*]third item
 *                 [/list]
 *               The [list] tag can have an additional parameter:
 *                 [list]   unorderer list with bullets
 *                 [list=1] ordered list 1,2,3,4,...
 *                 [list=i] ordered list i,ii,iii,iv,...
 *                 [list=I] ordered list I,II,III,IV,...
 *                 [list=a] ordered list a,b,c,d,...
 *                 [list=A] ordered list A,B,C,D,...
 *             - produces well-formed output
 *             - cleaned up the code
 * ------------------------------------------------------------
 */

function bbcode($message) {

  $preg = array(
    // Font and text manipulation ( [color] [size] [font] [align] )
    '/\[color=(.*?)(?::\w+)?\](.*?)\[\/color(?::\w+)?\]/si'   => "<span style=\"color:\\1\">\\2</span>",
    '/\[size=(.*?)(?::\w+)?\](.*?)\[\/size(?::\w+)?\]/si'     => "<span style=\"font-size:\\1px\">\\2</span>",
    '/\[font=(.*?)(?::\w+)?\](.*?)\[\/font(?::\w+)?\]/si'     => "<span style=\"font-family:\\1\">\\2</span>",
    '/\[align=(.*?)(?::\w+)?\](.*?)\[\/align(?::\w+)?\]/si'   => "<div style=\"text-align:\\1\">\\2</div>",
    '/\[b(?::\w+)?\](.*?)\[\/b(?::\w+)?\]/si'                 => "<b>\\1</b>",
    '/\[i(?::\w+)?\](.*?)\[\/i(?::\w+)?\]/si'                 => "<i>\\1</i>",
    '/\[u(?::\w+)?\](.*?)\[\/u(?::\w+)?\]/si'                 => "<u>\\1</u>",
    '/\[center(?::\w+)?\](.*?)\[\/center(?::\w+)?\]/si'       => "<div style=\"text-align:center\">\\1</div>",
    '/\[code(?::\w+)?\](.*?)\[\/code(?::\w+)?\]/si'           => "<div class=\"code\">\\1</div>",
    // [email]
    '/\[email(?::\w+)?\](.*?)\[\/email(?::\w+)?\]/si'         => "<a href=\"mailto:\\1\" class=\"ng_email\">\\1</a>",
    '/\[email=(.*?)(?::\w+)?\](.*?)\[\/email(?::\w+)?\]/si'   => "<a href=\"mailto:\\1\" class=\"ng_email\">\\2</a>",
    // [url]
    '/\[url(?::\w+)?\]www\.(.*?)\[\/url(?::\w+)?\]/si'        => "<a href=\"http://www.\\1\" class=\"ng_url\">\\1</a>",
    '/\[url(?::\w+)?\]((?:http|https|news|ftp)\:\/\/.*?)\[\/url(?::\w+)?\]/si'             => "<a href=\"\\1\" class=\"ng_url\">\\1</a>",
    '/\[url=((?:http|https|news|ftp)\:\/\/.*?)(?::\w+)?\](.*?)\[\/url(?::\w+)?\]/si'       => "<a href=\"\\1\" class=\"ng_url\">\\2</a>",
    '/\[url(?::\w+)?\](mailto\:.*?)\[\/url(?::\w+)?\]/si'             => "<a href=\"\\1\" class=\"ng_url\">\\1</a>",
    '/\[url=(mailto\:.*?)(?::\w+)?\](.*?)\[\/url(?::\w+)?\]/si'       => "<a href=\"\\1\" class=\"ng_url\">\\2</a>",
    // [img]
    '/\[img(?::\w+)?\]((?:http|https|ftp)\:\/\/.*?)\[\/img(?::\w+)?\]/si'             => "<img src=\"\\1\" border=\"0\" alt=\"image\"/>",
    '/\[img=(.*?)x(.*?)(?::\w+)?\]((?:http|https|ftp)\:\/\/.*?)\[\/img(?::\w+)?\]/si' => "<img width=\"\\1\" height=\"\\2\" src=\"\\3\" border=\"0\" alt=\"image\"/>",
    // [quote]
    '/\[quote(?::\w+)?\](.*?)\[\/quote(?::\w+)?\]/si'         => "<blockquote>\\1</blockquote>",
    '/\[quote=(?:&quot;|"|\')?(.*?)["\']?(?:&quot;|"|\')?\](.*?)\[\/quote(?::\w+)?\]/si'   => "<div class=\"ng_quote\">Quote \\1:<div class=\"ng_quote_body\">\\2</div></div>",
    // [list]
    '/\[\*(?::\w+)?\]\s*([^\[]*)/si'                          => "<li class=\"ng_list_item\">\\1</li>",
    '/\[list(?::\w+)?\](.*?)\[\/list(?::\w+)?\]/si'           => "<ul class=\"ng_list\">\\1</ul>",
    '/\[list(?::\w+)?\](.*?)\[\/list:u(?::\w+)?\]/s'          => "<ul class=\"ng_list\">\\1</ul>",
    '/\[list=1(?::\w+)?\](.*?)\[\/list(?::\w+)?\]/si'         => "<ol class=\"ng_list\" style=\"list-style-type: decimal;\">\\1</ol>",
    '/\[list=i(?::\w+)?\](.*?)\[\/list(?::\w+)?\]/s'          => "<ol class=\"ng_list\" style=\"list-style-type: lower-roman;\">\\1</ol>",
    '/\[list=I(?::\w+)?\](.*?)\[\/list(?::\w+)?\]/s'          => "<ol class=\"ng_list\" style=\"list-style-type: upper-roman;\">\\1</ol>",
    '/\[list=a(?::\w+)?\](.*?)\[\/list(?::\w+)?\]/s'          => "<ol class=\"ng_list\" style=\"list-style-type: lower-alpha;\">\\1</ol>",
    '/\[list=A(?::\w+)?\](.*?)\[\/list(?::\w+)?\]/s'          => "<ol class=\"ng_list\" style=\"list-style-type: upper-alpha;\">\\1</ol>",
    '/\[list(?::\w+)?\](.*?)\[\/list:o(?::\w+)?\]/s'          => "<ol class=\"ng_list\" style=\"list-style-type: decimal;\">\\1</ol>",
    // the following lines clean up our output a bit
    '/<ol(.*?)>(?:.*?)<li(.*?)>/si'         => "<ol\\1><li\\2>",
    '/<ul(.*?)>(?:.*?)<li(.*?)>/si'         => "<ul\\1><li\\2>",

// smilies

   '/\:angry:/si'  => "<img src='smilies/angry.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:arrow:/si'  => "<img src='smilies/arrow.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:blink:/si'  => "<img src='smilies/blink.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:blush:/si'  => "<img src='smilies/blush.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:bow:/si'  => "<img src='smilies/bow.gif' border=\"0\" alt=\"smiley\"/>",
  '/\://si' => "<img src='smilies/confused.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:-//si' => "<img src='smilies/confused.gif' border=\"0\" alt=\"smiley\"/>",
  '/\8-\)/si' => "<img src='smilies/cool1.gif' border=\"0\" alt=\"smiley\"/>",
  '/\8\)/si' => "<img src='smilies/cool1.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:\'-\(/si' => "<img src='smilies/cry.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:\'\(/si' => "<img src='smilies/cry.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:devil:/si'  => "<img src='smilies/devil.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:evil:/si'  => "<img src='smilies/evil.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:evilmad:/si'  => "<img src='smilies/evilmad.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:fun:/si'  => "<img src='smilies/fun.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:-D/si' => "<img src='smilies/grin.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:D/si' => "<img src='smilies/grin.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:idea:/si'  => "<img src='smilies/idea.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:innocent:/si'  => "<img src='smilies/innocent.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:kiss:/si'  => "<img src='smilies/kiss.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:lol:/si'  => "<img src='smilies/laugh.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:look:/si'  => "<img src='smilies/look.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:love:/si'  => "<img src='smilies/love.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:ninja:/si'  => "<img src='smilies/ninja.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:no:/si'  => "<img src='smilies/no.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:-\|/si' => "<img src='smilies/noexpression.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:\|/si' => "<img src='smilies/noexpression.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:nugget:/si'  => "<img src='smilies/nugget.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:-O/si' => "<img src='smilies/ohmy.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:O/si' => "<img src='smilies/ohmy.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:ras:/si'  => "<img src='smilies/ras.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:rolleyes:/si'  => "<img src='smilies/rolleyes.gif' border=\"0\" alt=\"smiley\"/>",
  '/\::\)/si'  => "<img src='smilies/rolleyes.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:-\(/si' => "<img src='smilies/sad.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:\(/si' => "<img src='smilies/sad.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:sick:/si'  => "<img src='smilies/sick.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:slap:/si'  => "<img src='smilies/slap.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:smartass:/si'  => "<img src='smilies/smartass.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:-\)/si' => "<img src='smilies/smile1.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:\)/si' => "<img src='smilies/smile1.gif' border=\"0\" alt=\"smiley\"/>",  
  '/\:thumbsup:/si'  => "<img src='smilies/thumbsup.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:thumbsdown:/si'  => "<img src='smilies/thumbsdown.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:-P/si' => "<img src='smilies/tongue.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:P/si' => "<img src='smilies/tongue.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:unsure:/si'  => "<img src='smilies/unsure.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:w00t:/si'  => "<img src='smilies/w00t.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:wall:/si'  => "<img src='smilies/wall.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:wave:/si'  => "<img src='smilies/wave.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:wavecry:/si'  => "<img src='smilies/wavecry.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:weirdo:/si'  => "<img src='smilies/weirdo.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:whistle:/si'  => "<img src='smilies/whistle.gif' border=\"0\" alt=\"smiley\"/>",
  '/\;-\)/si' => "<img src='smilies/wink.gif' border=\"0\" alt=\"smiley\"/>",
  '/\;\)/si' => "<img src='smilies/wink.gif' border=\"0\" alt=\"smiley\"/>",
  '/\:wub:/si'  => "<img src='smilies/wub.gif' border=\"0\" alt=\"smiley\"/>"
  );

  $message = preg_replace(array_keys($preg), array_values($preg), $message);

// make clickable() :
/**
 * Rewritten by Nathan Codding - Feb 6, 2001.
 * - Goes through the given string, and replaces xxxx://yyyy with an HTML <a> tag linking
 * 	to that URL
 * - Goes through the given string, and replaces www.xxxx.yyyy[zzzz] with an HTML <a> tag linking
 * 	to http://www.xxxx.yyyy[/zzzz]
 * - Goes through the given string, and replaces xxxx@yyyy with an HTML mailto: tag linking
 *		to that email address
 * - Only matches these 2 patterns either after a space, or at the beginning of a line
 *
 * Notes: the email one might get annoying - it's easy to make it more restrictive, though.. maybe
 * have it require something like xxxx@yyyy.zzzz or such. We'll see.
 */

	// pad it with a space so we can match things at the start of the 1st line.
	$ret = ' ' . $message;

	// matches an "xxxx://yyyy" URL at the start of a line, or after a space.
	// xxxx can only be alpha characters.
	// yyyy is anything up to the first space, newline, comma, double quote or <
	$ret = preg_replace("#([\t\r\n ])([a-z0-9]+?){1}://([\w\-]+\.([\w\-]+\.)*[\w]+(:[0-9]+)?(/[^ \"\n\r\t<]*)?)#i", '\1<a href="\2://\3">\2://\3</a>', $ret);

	// matches a "www|ftp.xxxx.yyyy[/zzzz]" kinda lazy URL thing
	// Must contain at least 2 dots. xxxx contains either alphanum, or "-"
	// zzzz is optional.. will contain everything up to the first space, newline,
	// comma, double quote or <.
	$ret = preg_replace("#([\t\r\n ])(www|ftp)\.(([\w\-]+\.)*[\w]+(:[0-9]+)?(/[^ \"\n\r\t<]*)?)#i", '\1<a href="http://\2.\3">\2.\3</a>', $ret);

	// matches an email@domain type address at the start of a line, or after a space.
	// Note: Only the followed chars are valid; alphanums, "-", "_" and or ".".
	$ret = preg_replace("#([\n ])([a-z0-9\-_.]+?)@([\w\-]+\.([\w\-\.]+\.)*[\w]+)#i", "\\1<a href=\"mailto:\\2@\\3\">\\2@\\3</a>", $ret);

	// Remove our padding..
	$ret = substr($ret, 1);

	return (nl2br($ret));
}


// for RSS:

function bbcode4rss($message) {
  $preg = array(
    '/\[color=(.*?)(?::\w+)?\](.*?)\[\/color(?::\w+)?\]/si'   => "\\2",
    '/\[size=(.*?)(?::\w+)?\](.*?)\[\/size(?::\w+)?\]/si'     => "\\2",
    '/\[font=(.*?)(?::\w+)?\](.*?)\[\/font(?::\w+)?\]/si'     => "\\2",
    '/\[align=(.*?)(?::\w+)?\](.*?)\[\/align(?::\w+)?\]/si'   => "\\2",
    '/\[b(?::\w+)?\](.*?)\[\/b(?::\w+)?\]/si'                 => "*\\1*",
    '/\[i(?::\w+)?\](.*?)\[\/i(?::\w+)?\]/si'                 => "_\\1_",
    '/\[u(?::\w+)?\](.*?)\[\/u(?::\w+)?\]/si'                 => "__\\1__",
    '/\[url(?::\w+)?\]www\.(.*?)\[\/url(?::\w+)?\]/si'        => "- URL: \\1 -",
    '/\[url(?::\w+)?\](.*?)\[\/url(?::\w+)?\]/si'             => "- URL: \\1 -",
    '/\[url=(.*?)(?::\w+)?\](.*?)\[\/url(?::\w+)?\]/si'       => "\\2 - URL: \\1 -",
    // [img]
    '/\[img(?::\w+)?\](.*?)\[\/img(?::\w+)?\]/si'             => "- Image: \\1 -",
    '/\[img=(.*?)x(.*?)(?::\w+)?\](.*?)\[\/img(?::\w+)?\]/si' => "- Image: \\1 -",
    // [quote]
    '/\[quote(?::\w+)?\](.*?)\[\/quote(?::\w+)?\]/si'         => "\"\\1\"",
    '/\[quote=(?:&quot;|"|\')?(.*?)["\']?(?:&quot;|"|\')?\](.*?)\[\/quote(?::\w+)?\]/si'   => " \\1: \"\\2\" ",
    // [list]
    '/\[\*(?::\w+)?\]\s*([^\[]*)/si'                          => "- \\1",
    '/\[list(?::\w+)?\](.*?)\[\/list(?::\w+)?\]/si'           => "- \\1",
    '/\[list(?::\w+)?\](.*?)\[\/list:u(?::\w+)?\]/s'          => "- \\1",
  );

  $message = preg_replace(array_keys($preg), array_values($preg), $message);

return ($message);

}



?>